<?php

namespace Drupal\bigin_crm;

use Drupal\bigin_crm\BiginAuthService;
use Drupal\bigin_crm\Rest\RestClient;

/**
 * To add new entities to the contacts module.
 */
class BiginContactsService {

  /**
   * The auth Service
   *
   * @var \Drupal\bigin_crm\BiginAuthService
   */
  protected $authService;

  /**
   * The rest client
   *
   * @var \Drupal\bigin_crm\Rest\RestClient
   */
  protected $client;

  /**
   * Constructs a new Service object.
   */
  public function __construct(BiginAuthService $authService, RestClient $client) {
    $this->authService = $authService;
    $this->client = $client;
  }

  /**
   * Add new contact to Bigin crm.
   *
   * @param array
   *   User data.
   *
   * @return string
   *   api rest response
   */
  public function create($user) 
  {
    $config = \Drupal::config('bigin_crm.settings');
    // user data
    $body['data'][0] = [
      "Last_Name" => $user['name'],
      "First_Name" => '',
      "Email" => $user['email'],
      "Owner" => [
        "id" => $config->get('deal_owner')
      ]
    ];
    
    $url = $this->authService->urlApi() . '/bigin/v1/Contacts';
    $response = $this->client->apiCall($url, [], $body, 'POST');

    if(!empty($response->data) && $response->data[0]->code == 'SUCCESS') {
      //add new deal to pipelines
      $res = \Drupal::service('bigin_crm.pipelines_service')->createDeal($response->data[0]->details->id, $user['name'], $user['roles']);
      return $res;
    }
  }

  /**
   * Get list users.
   *
   * @return array
   *   list users
   */
  public function getUsers() {
    $path = $this->authService->urlApi() . '/bigin/v1/users';
    $params = [
      'type' => 'AllUsers',
    ];

    $response = $this->client->apiCall($path, $params, []);
    return $response->users ?? [];
  }

}
