<?php

namespace Drupal\bigin_crm;

use Drupal\bigin_crm\BiginAuthService;
use Drupal\bigin_crm\Rest\RestClient;

/**
 * To add new deals to pipelines.
 */
class BiginPipelinesService {

  /**
   * The auth Service
   *
   * @var \Drupal\bigin_crm\BiginAuthService
   */
  protected $authService;

  /**
   * The rest client
   *
   * @var \Drupal\bigin_crm\Rest\RestClient
   */
  protected $client;

  /**
   * Constructs a new Service object.
   */
  public function __construct(BiginAuthService $authService, RestClient $client) {
    $this->authService = $authService;
    $this->client = $client;
  }

  /**
   * Add new deal.
   *
   * @param string $id
   *   The contact id.
   * @param string $name
   *   The contact name.
   *
   * @return string
   *   api rest response
   */

  public function createDeal($id, $name, $roles) {
    $config = \Drupal::config('bigin_crm.settings');
    $body = '{
      "data": [
        {
          "Deal_Name": "'.$config->get('deal_name').'",
          "Stage": "'.$config->get('stage').'",
          "Layout": {
            "name": "'.$config->get('layout_name').'",
            "id": "'.$config->get('layout').'"
          },
          "Contact_Name": {
            "name": "'.$name.'",
            "id": "'.$id.'"
          },
          "Closing_Date": "'.date('Y-m-d', strtotime($config->get('closing_date'))).'",
          "Pipeline": "'.$config->get('sub_pipeline').'",
          "Owner": {
            "id": "'.$config->get('deal_owner').'",
          },
          "Description": "'.$config->get('deal_description').'",
        }
      ]
    }';

    $url = $this->authService->urlApi() . '/bigin/v1/Deals';
    $response = $this->client->apiCall($url, [], $body, 'POST');
    return !empty($response->data) ? $response->data[0]->code : 'Error';
  }

  /**
   * To get list of the layouts.
   *
   * @return array
   *   list layouts
   */
  public function getLayouts() {
    $path = $this->authService->urlApi() . '/bigin/v1/settings/layouts';
    $params = [
      'module' => 'Deals',
    ];

    $response = $this->client->apiCall($path, $params, []);
    return $response->layouts ?? [];
  }
}
