<?php
/**
 * @file
 * Contains \Drupal\bigin_crm\Controller\BiginController.
 */
namespace Drupal\bigin_crm\Controller;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Url;
use Drupal\bigin_crm\BiginAuthService;

class BiginController extends ControllerBase {

  /**
   * Symfony\Component\HttpFoundation\Request definition.
   *
   * @var \Symfony\Component\HttpFoundation\Request|null
   */
  protected $currentRequest;

  /**
   * The Drupal messenger service.
   *
   * @var \Drupal\Core\Messenger\Messenger
   */
  protected $messenger;

  /**
   * The auth Service
   *
   * @var \Drupal\bigin_crm\BiginAuthService
   */
  protected $authService;

  public function __construct(RequestStack $request, Messenger $messenger, BiginAuthService $authService) {
    $this->currentRequest = $request->getCurrentRequest();
    $this->messenger = $messenger;
    $this->authService = $authService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack'),
      $container->get('messenger'),
      $container->get('bigin_crm.auth_service'),
    );
  }

  public function initialize()
  {
    $getTokenForm = $this->formBuilder()->getForm('Drupal\bigin_crm\Form\GetTokenForm');

    $config = \Drupal::config('bigin_crm.settings');
    //redirect url
    $redirect = Url::fromRoute('bigin_crm.callback',[], ['absolute' => true])->toString();
    //scopes for API requests to restrict clients from accessing unauthorized resources
    $scope = 'ZohoBigin.modules.contacts.CREATE,ZohoBigin.settings.layouts.READ,ZohoBigin.modules.deals.CREATE,ZohoBigin.users.READ';
    //The authorization request link
    $authUrl = $this->authService->urlAccount().'/oauth/v2/auth?scope='.$scope.'&client_id='.$config->get('client_id').
    '&response_type=code&access_type=offline&redirect_uri='.$redirect.'&prompt=consent';
    $revokeUrl = Url::fromRoute('bigin_crm.revoke',[])->toString();

    return [
      '#theme' => 'form_settings',
      '#form' => $getTokenForm,
      '#auth_url' => $authUrl,
      '#revoke_url' => $config->get('access_token') ? $revokeUrl : null,
    ];
  }

  /**
   * Bigin returns the user here after user has authenticated.
   * 
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   A redirect response to settings page.
   */
  public function callback() {
    if($this->currentRequest->query->has('code')) {
      // Get access tokens using authorization code 
      $access = $this->authService->generateAccessToken($this->currentRequest->query->get('code'));
      $this->messenger()->addMessage($access ? $this->t('Success') : $this->t('Failed'));
      return $this->redirect('bigin_crm.admin_settings_form');
    }
  }

  /**
   * Revoke the refresh token.
   * 
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   A redirect response to settings page.
   */
  public function revoke() {
    try {
      $data = $this->authService->revokeToken();
      $this->messenger->addMessage($data);
    } catch (GuzzleException $e) {
      $this->messenger->addMessage($this->t('We have problems trying revoke your token.'));
    }
    return $this->redirect('bigin_crm.admin_settings_form');
  }
}
