<?php

/**
 * @file
 * Pipeline configuration form.
 */

namespace Drupal\bigin_crm\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Path\PathValidatorInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;

class SettingsPipelinesForm extends ConfigFormBase
{
  /**
   * {@inheritdoc}
   */
  public function getFormId()
  {
    // Unique ID of the form.
    return 'bigin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames()
  {
    return [
      'bigin_crm.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state)
  {
    $config = $this->config('bigin_crm.settings');

    $form['pipelines'] = [
      '#type' => 'details',
      '#title' => $this->t('Module pipelines settings'),
      '#open' => true,
    ];

    $form['pipelines']['layout'] = [
      '#type' => 'select',
      '#required' => true,
      '#default_value' => $config->get('layout'),
      '#options' => $this->getLayouts(),
      '#title' => 'Pipeline',
      "#description" => $this->t('Select pipeline.')
    ];

    $form['pipelines']['sub_pipeline'] = [
      '#type' => 'textfield',
      '#required' => true,
      '#default_value' => $config->get('sub_pipeline'),
      '#title' => 'Sub-Pipeline',
      "#description" => $this->t('Enter Sub-Pipeline name.')
    ];

    $form['pipelines']['stage'] = [
      '#type' => 'textfield',
      '#required' => true,
      '#default_value' => $config->get('stage'),
      '#title' => 'Stage',
      "#description" => $this->t('Enter open stages name.')
    ];

    $form['pipelines']['closing_date'] = [
      '#type' => 'textfield',
      '#required' => true,
      '#default_value' => $config->get('closing_date'),
      '#title' => 'Closing Date',
      "#description" => $this->t('Enter closing date, example: +5 day.')
    ];

    $form['pipelines']['deal_owner'] = [
      '#type' => 'select',
      '#required' => true,
      '#default_value' => $config->get('deal_owner'),
      '#options' => $this->getUsers(),
      '#title' => 'Owner',
      "#description" => $this->t('Select the owner to assign to the deal and contact.')
    ];

    $form['pipelines']['deal_name'] = [
      '#type' => 'textfield',
      '#required' => true,
      '#default_value' => $config->get('deal_name'),
      '#title' => 'Deal name',
      "#description" => $this->t('Enter deal name.')
    ];

    $form['pipelines']['deal_description'] = [
      '#type' => 'textfield',
      '#required' => false,
      '#default_value' => $config->get('deal_description'),
      '#title' => 'Deal description',
      "#description" => $this->t('Enter deal description.')
    ];
    
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state)
  {
    $config_keys = [
     'layout', 'sub_pipeline', 'stage', 'closing_date', 'deal_name', 'deal_owner', 'deal_description'
    ];
    $crm_config = $this->config('bigin_crm.settings');
    foreach ($config_keys as $config_key) {
      if ($form_state->hasValue($config_key)) {
        $crm_config->set($config_key, $form_state->getValue($config_key));
      }
    }
    $crm_config->set('layout_name', $form['pipelines']['layout']['#options'][$form_state->getValue('layout')]);
    $crm_config->save();
    parent::submitForm($form, $form_state);
  }

  // get list layouts from bigin crm.
  private function getLayouts()
  {
    $data = [];
    $service = \Drupal::service('bigin_crm.pipelines_service');
    $allData = $service->getLayouts();

    foreach ($allData as $item) {
      $data[$item->id] = $item->name;
    }
    return $data;
  }

  // get list users from bigin crm.
  private function getUsers()
  {
    $data = [];
    $service = \Drupal::service('bigin_crm.contacts_service');
    $allData = $service->getUsers();

    foreach ($allData as $item) {
      $data[$item->id] = $item->first_name;
    }
    return $data;
  }
}
